@@ -2,6 +2,7 @@ package cli
 
 import (
 	"fmt"
+	"oh-my-posh/environment"
 	"oh-my-posh/font"
 
 	"github.com/spf13/cobra"
@@ -32,7 +33,10 @@ This command is used to install fonts and configure the font in your terminal.
 				if len(args) > 1 {
 					fontName = args[1]
 				}
-				font.Run(fontName)
+				env := &environment.ShellEnvironment{}
+				env.Init()
+				needsAdmin := env.GOOS() == environment.WINDOWS && !env.Root()
+				font.Run(fontName, needsAdmin)
 				return
 			case "configure":
 				fmt.Println("not implemented")
