@@ -140,6 +140,23 @@ func (a *Ansi) InitPlain() {
 }
 
 func (a *Ansi) GenerateHyperlink(text string) string {
+	parts := strings.SplitAfter(text, ")")
+	var buffer strings.Builder
+	var part string
+	for i := range parts {
+		part += parts[i]
+		if strings.Contains(parts[i], "[") && !strings.Contains(parts[i], "]") {
+			continue
+		}
+		buffer.WriteString(a.replaceHyperlink(part))
+		part = ""
+	}
+	// when we did not process any parts, we return the original text
+	buffer.WriteString(part)
+	return buffer.String()
+}
+
+func (a *Ansi) replaceHyperlink(text string) string {
 	// hyperlink matching
 	results := regex.FindNamedRegexMatch("(?P<ALL>(?:\\[(?P<TEXT>.+)\\])(?:\\((?P<URL>.*)\\)))", text)
 	if len(results) != 3 {
@@ -266,6 +283,13 @@ func (a *Ansi) ClearAfter() string {
 }
 
 func (a *Ansi) Title(title string) string {
+	// we have to do this to prevent bash/zsh from misidentifying escape sequences
+	switch a.shell {
+	case shell.BASH:
+		title = strings.NewReplacer("`", "\\`", `\`, `\\`).Replace(title)
+	case shell.ZSH:
+		title = strings.NewReplacer("`", "\\`", `%`, `%%`).Replace(title)
+	}
 	return fmt.Sprintf(a.title, title)
 }
 
