@@ -32,6 +32,7 @@ type Segment struct {
 	TemplatesLogic      template.Logic `json:"templates_logic,omitempty"`
 	Properties          properties.Map `json:"properties,omitempty"`
 	Interactive         bool           `json:"interactive,omitempty"`
+	Alias               string         `json:"alias,omitempty"`
 
 	writer          SegmentWriter
 	Enabled         bool `json:"-"`
@@ -95,10 +96,14 @@ const (
 	CMAKE SegmentType = "cmake"
 	// CMD writes the output of a shell command
 	CMD SegmentType = "command"
+	// CONNECTION writes a connection's information
+	CONNECTION SegmentType = "connection"
 	// CRYSTAL writes the active crystal version
 	CRYSTAL SegmentType = "crystal"
 	// DART writes the active dart version
 	DART SegmentType = "dart"
+	// DENO writes the active deno version
+	DENO SegmentType = "deno"
 	// DOTNET writes which dotnet version is currently active
 	DOTNET SegmentType = "dotnet"
 	// EXECUTIONTIME writes the execution time of the last run command
@@ -153,8 +158,6 @@ const (
 	PHP SegmentType = "php"
 	// PLASTIC represents the plastic scm status and information
 	PLASTIC SegmentType = "plastic"
-	// POSHGIT writes the posh git prompt
-	POSHGIT SegmentType = "poshgit"
 	// Project version
 	PROJECT SegmentType = "project"
 	// PYTHON writes the virtual env name
@@ -191,8 +194,6 @@ const (
 	UI5TOOLING SegmentType = "ui5tooling"
 	// WAKATIME writes tracked time spend in dev editors
 	WAKATIME SegmentType = "wakatime"
-	// WIFI writes details about the current WIFI connection
-	WIFI SegmentType = "wifi"
 	// WINREG queries the Windows registry.
 	WINREG SegmentType = "winreg"
 	// WITHINGS queries the Withings API.
@@ -276,9 +277,11 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		CF:            &segments.Cf{},
 		CFTARGET:      &segments.CfTarget{},
 		CMD:           &segments.Cmd{},
+		CONNECTION:    &segments.Connection{},
 		CRYSTAL:       &segments.Crystal{},
 		CMAKE:         &segments.Cmake{},
 		DART:          &segments.Dart{},
+		DENO:          &segments.Deno{},
 		DOTNET:        &segments.Dotnet{},
 		EXECUTIONTIME: &segments.Executiontime{},
 		EXIT:          &segments.Exit{},
@@ -306,7 +309,6 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		PERL:          &segments.Perl{},
 		PHP:           &segments.Php{},
 		PLASTIC:       &segments.Plastic{},
-		POSHGIT:       &segments.PoshGit{},
 		PROJECT:       &segments.Project{},
 		PYTHON:        &segments.Python{},
 		R:             &segments.R{},
@@ -325,7 +327,6 @@ func (segment *Segment) mapSegmentWithWriter(env environment.Environment) error
 		TIME:          &segments.Time{},
 		UI5TOOLING:    &segments.UI5Tooling{},
 		WAKATIME:      &segments.Wakatime{},
-		WIFI:          &segments.Wifi{},
 		WINREG:        &segments.WindowsRegistry{},
 		WITHINGS:      &segments.Withings{},
 		YTM:           &segments.Ytm{},
@@ -345,7 +346,7 @@ func (segment *Segment) string() string {
 	var templatesResult string
 	if !segment.Templates.Empty() {
 		templatesResult = segment.Templates.Resolve(segment.writer, segment.env, "", segment.TemplatesLogic)
-		if len(templatesResult) != 0 && len(segment.Template) == 0 {
+		if len(segment.Template) == 0 {
 			return templatesResult
 		}
 	}
@@ -382,7 +383,11 @@ func (segment *Segment) SetEnabled(env environment.Environment) {
 	}
 	if segment.writer.Enabled() {
 		segment.Enabled = true
-		env.TemplateCache().AddSegmentData(string(segment.Type), segment.writer)
+		name := segment.Alias
+		if len(name) == 0 {
+			name = string(segment.Type)
+		}
+		env.TemplateCache().AddSegmentData(name, segment.writer)
 	}
 }
 
@@ -395,11 +400,11 @@ func (segment *Segment) SetText() {
 	if segment.Interactive {
 		return
 	}
+	// we have to do this to prevent bash/zsh from misidentifying escape sequences
 	switch segment.env.Shell() {
-	case shell.BASH, shell.FISH:
-		segment.text = strings.ReplaceAll(segment.text, `\`, `\\`)
+	case shell.BASH:
+		segment.text = strings.NewReplacer("`", "\\`", `\`, `\\`).Replace(segment.text)
 	case shell.ZSH:
-		segment.text = strings.ReplaceAll(segment.text, `%`, `%%`)
+		segment.text = strings.NewReplacer("`", "\\`", `%`, `%%`).Replace(segment.text)
 	}
-	segment.text = strings.ReplaceAll(segment.text, "`", "'")
 }
