@@ -54,6 +54,7 @@ type Flags struct {
 	TerminalWidth int
 	Strict        bool
 	Debug         bool
+	Manual        bool
 }
 
 type CommandError struct {
@@ -97,20 +98,27 @@ type WindowsRegistryValue struct {
 	String    string
 }
 
-type WifiType string
+type NotImplemented struct{}
 
-type WifiInfo struct {
-	SSID           string
-	Interface      string
-	RadioType      WifiType
-	PhysType       WifiType
-	Authentication WifiType
-	Cipher         WifiType
-	Channel        int
-	ReceiveRate    int
-	TransmitRate   int
-	Signal         int
-	Error          string
+func (n *NotImplemented) Error() string {
+	return "not implemented"
+}
+
+type ConnectionType string
+
+const (
+	ETHERNET  ConnectionType = "ethernet"
+	WIFI      ConnectionType = "wifi"
+	CELLULAR  ConnectionType = "cellular"
+	BLUETOOTH ConnectionType = "bluetooth"
+)
+
+type Connection struct {
+	Name         string
+	Type         ConnectionType
+	TransmitRate uint64
+	ReceiveRate  uint64
+	SSID         string // Wi-Fi only
 }
 
 type TemplateCache struct {
@@ -181,7 +189,7 @@ type Environment interface {
 	InWSLSharedDrive() bool
 	ConvertToLinuxPath(path string) string
 	ConvertToWindowsPath(path string) string
-	WifiNetwork() (*WifiInfo, error)
+	Connection(connectionType ConnectionType) (*Connection, error)
 	TemplateCache() *TemplateCache
 	LoadTemplateCache()
 	Log(logType LogType, funcName, message string)
@@ -221,6 +229,7 @@ type ShellEnvironment struct {
 	fileCache  *fileCache
 	tmplCache  *TemplateCache
 	logBuilder strings.Builder
+	networks   []*Connection
 }
 
 func (env *ShellEnvironment) Init() {
@@ -245,7 +254,7 @@ func (env *ShellEnvironment) resolveConfigPath() {
 		env.CmdFlags.Config = env.Getenv("POSH_THEME")
 	}
 	if len(env.CmdFlags.Config) == 0 {
-		env.CmdFlags.Config = fmt.Sprintf("https://raw.githubusercontent.com/JanDeDobbeleer/oh-my-posh/v%s/themes/default.omp.json", env.Version)
+		return
 	}
 	if strings.HasPrefix(env.CmdFlags.Config, "https://") {
 		if err := env.downloadConfig(env.CmdFlags.Config); err != nil {
@@ -335,6 +344,9 @@ func (env *ShellEnvironment) Pwd() string {
 		return env.cwd
 	}
 	correctPath := func(pwd string) string {
+		if env.GOOS() != WINDOWS {
+			return pwd
+		}
 		// on Windows, and being case sensitive and not consistent and all, this gives silly issues
 		driveLetter := regex.GetCompiledRegex(`^[a-z]:`)
 		return driveLetter.ReplaceAllStringFunc(pwd, strings.ToUpper)
@@ -574,9 +586,14 @@ func (env *ShellEnvironment) Shell() string {
 		env.Log(Error, "Shell", err.Error())
 		return UNKNOWN
 	}
-	if name == "cmd.exe" {
+	env.Log(Debug, "Shell", "process name: "+name)
+	// this is used for when scoop creates a shim, see
+	// https://github.com/JanDeDobbeleer/oh-my-posh/issues/2806
+	executable, _ := os.Executable()
+	if name == "cmd.exe" || name == executable {
 		p, _ = p.Parent()
 		name, err = p.Name()
+		env.Log(Debug, "Shell", "parent process name: "+name)
 	}
 	if err != nil {
 		env.Log(Error, "Shell", err.Error())
@@ -727,9 +744,11 @@ func (env *ShellEnvironment) TemplateCache() *TemplateCache {
 		tmplCache.Env[key] = strings.Join(val, separator)
 	}
 	pwd := env.Pwd()
-	pwd = strings.Replace(pwd, env.Home(), "~", 1)
-	tmplCache.PWD = pwd
+	tmplCache.PWD = ReplaceHomeDirPrefixWithTilde(env, pwd)
 	tmplCache.Folder = Base(env, pwd)
+	if env.GOOS() == WINDOWS && strings.HasSuffix(tmplCache.Folder, ":") {
+		tmplCache.Folder += `\`
+	}
 	tmplCache.UserName = env.User()
 	if host, err := env.Host(); err == nil {
 		tmplCache.HostName = host
@@ -761,19 +780,21 @@ func (env *ShellEnvironment) DirMatchesOneOf(dir string, regexes []string) (matc
 }
 
 func dirMatchesOneOf(dir, home, goos string, regexes []string) bool {
-	normalizedCwd := strings.ReplaceAll(dir, "\\", "/")
-	normalizedHomeDir := strings.ReplaceAll(home, "\\", "/")
+	if goos == WINDOWS {
+		dir = strings.ReplaceAll(dir, "\\", "/")
+		home = strings.ReplaceAll(home, "\\", "/")
+	}
 
 	for _, element := range regexes {
 		normalizedElement := strings.ReplaceAll(element, "\\\\", "/")
 		if strings.HasPrefix(normalizedElement, "~") {
-			normalizedElement = strings.Replace(normalizedElement, "~", normalizedHomeDir, 1)
+			normalizedElement = strings.Replace(normalizedElement, "~", home, 1)
 		}
 		pattern := fmt.Sprintf("^%s$", normalizedElement)
 		if goos == WINDOWS || goos == DARWIN {
 			pattern = "(?i)" + pattern
 		}
-		matched := regex.MatchString(pattern, normalizedCwd)
+		matched := regex.MatchString(pattern, dir)
 		if matched {
 			return true
 		}
@@ -781,18 +802,28 @@ func dirMatchesOneOf(dir, home, goos string, regexes []string) bool {
 	return false
 }
 
+func IsPathSeparator(env Environment, c uint8) bool {
+	if c == '/' {
+		return true
+	}
+	if env.GOOS() == WINDOWS && c == '\\' {
+		return true
+	}
+	return false
+}
+
 // Base returns the last element of path.
 // Trailing path separators are removed before extracting the last element.
 // If the path consists entirely of separators, Base returns a single separator.
 func Base(env Environment, path string) string {
-	if path == "/" {
-		return path
-	}
 	volumeName := filepath.VolumeName(path)
 	// Strip trailing slashes.
-	for len(path) > 0 && string(path[len(path)-1]) == env.PathSeparator() {
+	for len(path) > 0 && IsPathSeparator(env, path[len(path)-1]) {
 		path = path[0 : len(path)-1]
 	}
+	if len(path) == 0 {
+		return env.PathSeparator()
+	}
 	if volumeName == path {
 		return path
 	}
@@ -800,19 +831,32 @@ func Base(env Environment, path string) string {
 	path = path[len(filepath.VolumeName(path)):]
 	// Find the last element
 	i := len(path) - 1
-	for i >= 0 && string(path[i]) != env.PathSeparator() {
+	for i >= 0 && !IsPathSeparator(env, path[i]) {
 		i--
 	}
 	if i >= 0 {
 		path = path[i+1:]
 	}
 	// If empty now, it had only slashes.
-	if path == "" {
+	if len(path) == 0 {
 		return env.PathSeparator()
 	}
 	return path
 }
 
+func ReplaceHomeDirPrefixWithTilde(env Environment, path string) string {
+	home := env.Home()
+	// match Home directory exactly
+	if !strings.HasPrefix(path, home) {
+		return path
+	}
+	rem := path[len(home):]
+	if len(rem) == 0 || IsPathSeparator(env, rem[0]) {
+		return "~" + rem
+	}
+	return path
+}
+
 func cleanHostName(hostName string) string {
 	garbage := []string{
 		".lan",
