@@ -22,29 +22,6 @@ func TestHostNameWithLan(t *testing.T) {
 	assert.Equal(t, "hello", cleanHostName)
 }
 
-func TestWindowsPathWithDriveLetter(t *testing.T) {
-	cases := []struct {
-		Case     string
-		CWD      string
-		Expected string
-	}{
-		{Case: "C drive", CWD: `C:\Windows\`, Expected: `C:\Windows\`},
-		{Case: "C drive lower case", CWD: `c:\Windows\`, Expected: `C:\Windows\`},
-		{Case: "P drive lower case", CWD: `p:\some\`, Expected: `P:\some\`},
-		{Case: "some drive lower case", CWD: `some:\some\`, Expected: `some:\some\`},
-		{Case: "drive ending in c:", CWD: `src:\source\`, Expected: `src:\source\`},
-		{Case: "registry drive", CWD: `HKLM:\SOFTWARE\magnetic:test\`, Expected: `HKLM:\SOFTWARE\magnetic:test\`},
-	}
-	for _, tc := range cases {
-		env := &ShellEnvironment{
-			CmdFlags: &Flags{
-				PWD: tc.CWD,
-			},
-		}
-		assert.Equal(t, env.Pwd(), tc.Expected)
-	}
-}
-
 func TestDirMatchesOneOf(t *testing.T) {
 	cases := []struct {
 		GOOS     string
