@@ -5,8 +5,8 @@ import (
 	"oh-my-posh/environment"
 	"oh-my-posh/properties"
 	"oh-my-posh/regex"
+	"oh-my-posh/shell"
 	"oh-my-posh/template"
-	"path/filepath"
 	"sort"
 	"strings"
 )
@@ -15,7 +15,10 @@ type Path struct {
 	props properties.Properties
 	env   environment.Environment
 
-	pwd        string
+	root     string
+	relative string
+	pwd      string
+
 	Path       string
 	StackCount int
 	Location   string
@@ -45,7 +48,7 @@ const (
 	Full string = "full"
 	// Folder displays the current folder
 	Folder string = "folder"
-	// Mixed like agnoster, but if the path is short it displays it
+	// Mixed like agnoster, but if a folder name is short enough, it is displayed as-is
 	Mixed string = "mixed"
 	// Letter like agnoster, but with the first letter of each folder name
 	Letter string = "letter"
@@ -70,7 +73,66 @@ func (pt *Path) Template() string {
 }
 
 func (pt *Path) Enabled() bool {
+	pt.setPaths()
+	if len(pt.pwd) == 0 {
+		return false
+	}
+	pt.setStyle()
+	pwd := pt.env.Pwd()
+	if pt.env.IsWsl() {
+		pt.Location, _ = pt.env.RunCommand("wslpath", "-m", pwd)
+	} else {
+		pt.Location = pwd
+	}
+	pt.StackCount = pt.env.StackCount()
+	pt.Writable = pt.env.DirIsWritable(pwd)
+	return true
+}
+
+func (pt *Path) setPaths() {
 	pt.pwd = pt.env.Pwd()
+	if (pt.env.Shell() == shell.PWSH || pt.env.Shell() == shell.PWSH5) && len(pt.env.Flags().PSWD) != 0 {
+		pt.pwd = pt.env.Flags().PSWD
+	}
+	if len(pt.pwd) == 0 {
+		return
+	}
+	// ensure a clean path
+	pt.root, pt.relative = pt.replaceMappedLocations()
+	pathSeparator := pt.env.PathSeparator()
+	if !strings.HasSuffix(pt.root, pathSeparator) && len(pt.relative) > 0 {
+		pt.pwd = pt.root + pathSeparator + pt.relative
+		return
+	}
+	pt.pwd = pt.root + pt.relative
+}
+
+func (pt *Path) Parent() string {
+	if len(pt.pwd) == 0 {
+		return ""
+	}
+	if len(pt.relative) == 0 {
+		// a root path has no parent
+		return ""
+	}
+	base := environment.Base(pt.env, pt.pwd)
+	path := pt.replaceFolderSeparators(pt.pwd[:len(pt.pwd)-len(base)])
+	return path
+}
+
+func (pt *Path) Init(props properties.Properties, env environment.Environment) {
+	pt.props = props
+	pt.env = env
+}
+
+func (pt *Path) setStyle() {
+	if len(pt.relative) == 0 {
+		pt.Path = pt.root
+		if strings.HasSuffix(pt.Path, ":") {
+			pt.Path += pt.env.PathSeparator()
+		}
+		return
+	}
 	switch style := pt.props.GetString(properties.Style, Agnoster); style {
 	case Agnoster:
 		pt.Path = pt.getAgnosterPath()
@@ -96,49 +158,17 @@ func (pt *Path) Enabled() bool {
 	default:
 		pt.Path = fmt.Sprintf("Path style: %s is not available", style)
 	}
-	pt.Path = pt.formatWindowsDrive(pt.Path)
-	if pt.env.IsWsl() {
-		pt.Location, _ = pt.env.RunCommand("wslpath", "-m", pt.pwd)
-	} else {
-		pt.Location = pt.pwd
-	}
-
-	pt.StackCount = pt.env.StackCount()
-	pt.Writable = pt.env.DirIsWritable(pt.pwd)
-	return true
-}
-
-func (pt *Path) Parent() string {
-	if pt.pwd == pt.env.Home() {
-		return ""
-	}
-	parent := filepath.Dir(pt.pwd)
-	if pt.pwd == parent {
-		return ""
-	}
-	separator := pt.env.PathSeparator()
-	if parent == pt.rootLocation() || parent == separator {
-		separator = ""
-	}
-	return pt.replaceMappedLocations(parent) + separator
-}
-
-func (pt *Path) formatWindowsDrive(pwd string) string {
-	if pt.env.GOOS() != environment.WINDOWS || !strings.HasSuffix(pwd, ":") {
-		return pwd
-	}
-	return pwd + "\\"
-}
-
-func (pt *Path) Init(props properties.Properties, env environment.Environment) {
-	pt.props = props
-	pt.env = env
 }
 
 func (pt *Path) getFolderSeparator() string {
 	separatorTemplate := pt.props.GetString(FolderSeparatorTemplate, "")
 	if len(separatorTemplate) == 0 {
-		return pt.props.GetString(FolderSeparatorIcon, pt.env.PathSeparator())
+		separator := pt.props.GetString(FolderSeparatorIcon, pt.env.PathSeparator())
+		// if empty, use the default separator
+		if len(separator) == 0 {
+			return pt.env.PathSeparator()
+		}
+		return separator
 	}
 	tmpl := &template.Text{
 		Template: separatorTemplate,
@@ -149,67 +179,77 @@ func (pt *Path) getFolderSeparator() string {
 	if err != nil {
 		pt.env.Log(environment.Error, "getFolderSeparator", err.Error())
 	}
+	if len(text) == 0 {
+		return pt.env.PathSeparator()
+	}
 	return text
 }
 
 func (pt *Path) getMixedPath() string {
 	var buffer strings.Builder
-	pwd := pt.getPwd()
-	splitted := strings.Split(pwd, pt.env.PathSeparator())
 	threshold := int(pt.props.GetFloat64(MixedThreshold, 4))
-	for i, part := range splitted {
-		if part == "" {
-			continue
-		}
-
-		folder := part
-		if len(part) > threshold && i != 0 && i != len(splitted)-1 {
-			folder = pt.props.GetString(FolderIcon, "..")
-		}
-		separator := pt.getFolderSeparator()
-		if i == 0 {
-			separator = ""
+	folderIcon := pt.props.GetString(FolderIcon, "..")
+	separator := pt.getFolderSeparator()
+	elements := strings.Split(pt.relative, pt.env.PathSeparator())
+	if pt.root != pt.env.PathSeparator() {
+		elements = append([]string{pt.root}, elements...)
+	}
+	n := len(elements)
+	buffer.WriteString(elements[0])
+	for i := 1; i < n; i++ {
+		folder := elements[i]
+		if len(folder) > threshold && i != n-1 {
+			folder = folderIcon
 		}
 		buffer.WriteString(fmt.Sprintf("%s%s", separator, folder))
 	}
-
 	return buffer.String()
 }
 
+func (pt *Path) pathDepth(pwd string) int {
+	splitted := strings.Split(pwd, pt.env.PathSeparator())
+	depth := 0
+	for _, part := range splitted {
+		if part != "" {
+			depth++
+		}
+	}
+	return depth
+}
+
 func (pt *Path) getAgnosterPath() string {
 	var buffer strings.Builder
-	pwd := pt.getPwd()
-	buffer.WriteString(pt.rootLocation())
-	pathDepth := pt.pathDepth(pwd)
 	folderIcon := pt.props.GetString(FolderIcon, "..")
 	separator := pt.getFolderSeparator()
-	for i := 1; i < pathDepth; i++ {
+	elements := strings.Split(pt.relative, pt.env.PathSeparator())
+	if pt.root != pt.env.PathSeparator() {
+		elements = append([]string{pt.root}, elements...)
+	}
+	n := len(elements)
+	buffer.WriteString(elements[0])
+	for i := 2; i < n; i++ {
 		buffer.WriteString(fmt.Sprintf("%s%s", separator, folderIcon))
 	}
-	if pathDepth > 0 {
-		buffer.WriteString(fmt.Sprintf("%s%s", separator, environment.Base(pt.env, pwd)))
+	if n > 1 {
+		buffer.WriteString(fmt.Sprintf("%s%s", separator, elements[n-1]))
 	}
 	return buffer.String()
 }
 
 func (pt *Path) getAgnosterLeftPath() string {
-	pwd := pt.getPwd()
-	separator := pt.env.PathSeparator()
-	pwd = strings.Trim(pwd, separator)
-	splitted := strings.Split(pwd, separator)
-	folderIcon := pt.props.GetString(FolderIcon, "..")
-	separator = pt.getFolderSeparator()
-	switch len(splitted) {
-	case 0:
-		return ""
-	case 1:
-		return splitted[0]
-	case 2:
-		return fmt.Sprintf("%s%s%s", splitted[0], separator, splitted[1])
-	}
 	var buffer strings.Builder
-	buffer.WriteString(fmt.Sprintf("%s%s%s", splitted[0], separator, splitted[1]))
-	for i := 2; i < len(splitted); i++ {
+	folderIcon := pt.props.GetString(FolderIcon, "..")
+	separator := pt.getFolderSeparator()
+	elements := strings.Split(pt.relative, pt.env.PathSeparator())
+	if pt.root != pt.env.PathSeparator() {
+		elements = append([]string{pt.root}, elements...)
+	}
+	n := len(elements)
+	buffer.WriteString(elements[0])
+	if n > 1 {
+		buffer.WriteString(fmt.Sprintf("%s%s", separator, elements[1]))
+	}
+	for i := 2; i < n; i++ {
 		buffer.WriteString(fmt.Sprintf("%s%s", separator, folderIcon))
 	}
 	return buffer.String()
@@ -218,7 +258,7 @@ func (pt *Path) getAgnosterLeftPath() string {
 func (pt *Path) getRelevantLetter(folder string) string {
 	// check if there is at least a letter we can use
 	matches := regex.FindNamedRegexMatch(`(?P<letter>[\p{L}0-9]).*`, folder)
-	if matches == nil || matches["letter"] == "" {
+	if matches == nil || len(matches["letter"]) == 0 {
 		// no letter found, keep the folder unchanged
 		return folder
 	}
@@ -230,34 +270,34 @@ func (pt *Path) getRelevantLetter(folder string) string {
 
 func (pt *Path) getLetterPath() string {
 	var buffer strings.Builder
-	pwd := pt.getPwd()
-	splitted := strings.Split(pwd, pt.env.PathSeparator())
 	separator := pt.getFolderSeparator()
-	for i := 0; i < len(splitted)-1; i++ {
-		folder := splitted[i]
-		if len(folder) == 0 {
-			continue
+	elements := strings.Split(pt.relative, pt.env.PathSeparator())
+	if pt.root != pt.env.PathSeparator() {
+		elements = append([]string{pt.root}, elements...)
+	}
+	n := len(elements)
+	for i := 0; i < n-1; i++ {
+		letter := pt.getRelevantLetter(elements[i])
+		if i != 0 {
+			buffer.WriteString(separator)
 		}
-		letter := pt.getRelevantLetter(folder)
-		buffer.WriteString(fmt.Sprintf("%s%s", letter, separator))
-	}
-	if len(splitted) > 0 {
-		buffer.WriteString(splitted[len(splitted)-1])
+		buffer.WriteString(letter)
 	}
+	buffer.WriteString(fmt.Sprintf("%s%s", separator, elements[n-1]))
 	return buffer.String()
 }
 
 func (pt *Path) getUniqueLettersPath() string {
 	var buffer strings.Builder
-	pwd := pt.getPwd()
-	splitted := strings.Split(pwd, pt.env.PathSeparator())
 	separator := pt.getFolderSeparator()
-	letters := make(map[string]bool, len(splitted))
-	for i := 0; i < len(splitted)-1; i++ {
-		folder := splitted[i]
-		if len(folder) == 0 {
-			continue
-		}
+	elements := strings.Split(pt.relative, pt.env.PathSeparator())
+	if pt.root != pt.env.PathSeparator() {
+		elements = append([]string{pt.root}, elements...)
+	}
+	n := len(elements)
+	letters := make(map[string]bool)
+	for i := 0; i < n-1; i++ {
+		folder := elements[i]
 		letter := pt.getRelevantLetter(folder)
 		for letters[letter] {
 			if letter == folder {
@@ -266,99 +306,87 @@ func (pt *Path) getUniqueLettersPath() string {
 			letter += folder[len(letter) : len(letter)+1]
 		}
 		letters[letter] = true
-		buffer.WriteString(fmt.Sprintf("%s%s", letter, separator))
-	}
-	if len(splitted) > 0 {
-		buffer.WriteString(splitted[len(splitted)-1])
+		if i != 0 {
+			buffer.WriteString(separator)
+		}
+		buffer.WriteString(letter)
 	}
+	buffer.WriteString(fmt.Sprintf("%s%s", separator, elements[n-1]))
 	return buffer.String()
 }
 
 func (pt *Path) getAgnosterFullPath() string {
-	pwd := pt.getPwd()
-	for len(pwd) > 1 && string(pwd[0]) == pt.env.PathSeparator() {
-		pwd = pwd[1:]
+	path := strings.Trim(pt.relative, pt.env.PathSeparator())
+	path = pt.replaceFolderSeparators(path)
+	if pt.root == pt.env.PathSeparator() {
+		return path
 	}
-	return pt.replaceFolderSeparators(pwd)
+	return pt.root + pt.getFolderSeparator() + path
 }
 
 func (pt *Path) getAgnosterShortPath() string {
-	pwd := pt.getPwd()
-	pathDepth := pt.pathDepth(pwd)
+	pathDepth := pt.pathDepth(pt.relative)
 	maxDepth := pt.props.GetInt(MaxDepth, 1)
 	if maxDepth < 1 {
 		maxDepth = 1
 	}
+	folderIcon := pt.props.GetString(FolderIcon, "..")
 	hideRootLocation := pt.props.GetBool(HideRootLocation, false)
-	if hideRootLocation {
-		// 1-indexing to avoid showing the root location when exceeding the max depth
-		pathDepth++
-	}
 	if pathDepth <= maxDepth {
+		if hideRootLocation {
+			pt.root = folderIcon
+		}
 		return pt.getAgnosterFullPath()
 	}
-	folderSeparator := pt.getFolderSeparator()
 	pathSeparator := pt.env.PathSeparator()
-	splitted := strings.Split(pwd, pathSeparator)
-	fullPathDepth := len(splitted)
-	splitPos := fullPathDepth - maxDepth
+	folderSeparator := pt.getFolderSeparator()
+	rel := strings.TrimPrefix(pt.relative, pathSeparator)
+	splitted := strings.Split(rel, pathSeparator)
+	splitPos := pathDepth - maxDepth
 	var buffer strings.Builder
-	if hideRootLocation {
-		buffer.WriteString(splitted[splitPos])
-		splitPos++
-	} else {
-		folderIcon := pt.props.GetString(FolderIcon, "..")
-		root := pt.rootLocation()
-		buffer.WriteString(fmt.Sprintf("%s%s%s", root, folderSeparator, folderIcon))
+	// unix root, needs to be replaced with the folder we're in at root level
+	root := pt.root
+	room := pathDepth - maxDepth
+	if root == pathSeparator {
+		root = splitted[0]
+		room--
 	}
-	for i := splitPos; i < fullPathDepth; i++ {
+	if hideRootLocation {
+		buffer.WriteString(folderIcon)
+	} else {
+		buffer.WriteString(root)
+		if room > 0 {
+			buffer.WriteString(folderSeparator)
+			buffer.WriteString(folderIcon)
+		}
+	}
+	for i := splitPos; i < pathDepth; i++ {
 		buffer.WriteString(fmt.Sprintf("%s%s", folderSeparator, splitted[i]))
 	}
 	return buffer.String()
 }
 
 func (pt *Path) getFullPath() string {
-	pwd := pt.getPwd()
-	return pt.replaceFolderSeparators(pwd)
+	rel := pt.relative
+	pathSeparator := pt.env.PathSeparator()
+	if pt.root != pathSeparator && !strings.HasSuffix(pt.root, pathSeparator) {
+		rel = pathSeparator + rel
+	}
+	path := pt.replaceFolderSeparators(rel)
+	return pt.root + path
 }
 
 func (pt *Path) getFolderPath() string {
-	pwd := pt.getPwd()
-	pwd = environment.Base(pt.env, pwd)
+	pwd := environment.Base(pt.env, pt.pwd)
 	return pt.replaceFolderSeparators(pwd)
 }
 
-func (pt *Path) getPwd() string {
-	pwd := pt.env.Flags().PSWD
-	if pwd == "" {
-		pwd = pt.env.Pwd()
-	}
-	pwd = pt.replaceMappedLocations(pwd)
-	return pwd
-}
-
-func (pt *Path) normalize(inputPath string) string {
-	normalized := inputPath
-	if strings.HasPrefix(inputPath, "~") {
-		normalized = pt.env.Home() + normalized[1:]
-	}
-	normalized = strings.ReplaceAll(normalized, "\\", "/")
-	goos := pt.env.GOOS()
-	if goos == environment.WINDOWS || goos == environment.DARWIN {
-		normalized = strings.ToLower(normalized)
-	}
-	return normalized
-}
-
-func (pt *Path) replaceMappedLocations(pwd string) string {
-	if strings.HasPrefix(pwd, "Microsoft.PowerShell.Core\\FileSystem::") {
-		pwd = strings.Replace(pwd, "Microsoft.PowerShell.Core\\FileSystem::", "", 1)
-	}
-
+func (pt *Path) replaceMappedLocations() (string, string) {
 	mappedLocations := map[string]string{}
+	// predefined mapped locations, can be disabled
 	if pt.props.GetBool(MappedLocationsEnabled, true) {
-		mappedLocations["HKCU:"] = pt.props.GetString(WindowsRegistryIcon, "\uF013")
-		mappedLocations["HKLM:"] = pt.props.GetString(WindowsRegistryIcon, "\uF013")
+		mappedLocations["hkcu:"] = pt.props.GetString(WindowsRegistryIcon, "\uF013")
+		mappedLocations["hklm:"] = pt.props.GetString(WindowsRegistryIcon, "\uF013")
 		mappedLocations[pt.normalize(pt.env.Home())] = pt.props.GetString(HomeIcon, "~")
 	}
 
@@ -366,35 +394,124 @@ func (pt *Path) replaceMappedLocations(pwd string) string {
 	// mapped locations can override predefined locations
 	keyValues := pt.props.GetKeyValueMap(MappedLocations, make(map[string]string))
 	for key, val := range keyValues {
-		mappedLocations[pt.normalize(key)] = val
+		if key != "" {
+			mappedLocations[pt.normalize(key)] = val
+		}
 	}
 
 	// sort map keys in reverse order
 	// fixes case when a subfoder and its parent are mapped
 	// ex /users/test and /users/test/dev
-	keys := make([]string, len(mappedLocations))
-	i := 0
+	keys := make([]string, 0, len(mappedLocations))
 	for k := range mappedLocations {
-		keys[i] = k
-		i++
+		keys = append(keys, k)
 	}
 	sort.Sort(sort.Reverse(sort.StringSlice(keys)))
 
-	normalizedPwd := pt.normalize(pwd)
+	root, relative := pt.parsePath(pt.pwd)
+	rootN := pt.normalize(root)
+	relativeN := pt.normalize(relative)
+	pathSeparator := pt.env.PathSeparator()
+
 	for _, key := range keys {
-		if strings.HasPrefix(normalizedPwd, key) {
-			value := mappedLocations[key]
-			return value + pwd[len(key):]
+		keyRoot, keyRelative := pt.parsePath(key)
+		if keyRoot != rootN || !strings.HasPrefix(relativeN, keyRelative) {
+			continue
+		}
+		value := mappedLocations[key]
+		overflow := relative[len(keyRelative):]
+		if len(overflow) == 0 {
+			// exactly match the full path
+			return value, ""
+		}
+		if len(keyRelative) == 0 {
+			// only match the root
+			return value, strings.Trim(relative, pathSeparator)
+		}
+		// match several prefix elements
+		if overflow[0:1] == pt.env.PathSeparator() {
+			return value, strings.Trim(overflow, pathSeparator)
 		}
 	}
-	return pwd
+	return root, strings.Trim(relative, pathSeparator)
+}
+
+func (pt *Path) normalizePath(path string) string {
+	if pt.env.GOOS() != environment.WINDOWS {
+		return path
+	}
+	var clean []rune
+	for _, char := range path {
+		var lastChar rune
+		if len(clean) > 0 {
+			lastChar = clean[len(clean)-1:][0]
+		}
+		if char == '/' && lastChar != 60 { // 60 == <, this is done to ovoid replacing color codes
+			clean = append(clean, 92) // 92 == \
+			continue
+		}
+		clean = append(clean, char)
+	}
+	return string(clean)
+}
+
+// ParsePath parses an input path and returns a clean root and a clean path.
+func (pt *Path) parsePath(inputPath string) (root, path string) {
+	if len(inputPath) == 0 {
+		return
+	}
+	separator := pt.env.PathSeparator()
+	clean := func(path string) string {
+		matches := regex.FindAllNamedRegexMatch(fmt.Sprintf(`(?P<element>[^\%s]+)`, separator), path)
+		n := len(matches) - 1
+		s := new(strings.Builder)
+		for i, m := range matches {
+			s.WriteString(m["element"])
+			if i != n {
+				s.WriteString(separator)
+			}
+		}
+		return s.String()
+	}
+
+	if pt.env.GOOS() == environment.WINDOWS {
+		inputPath = pt.normalizePath(inputPath)
+		// for a UNC path, extract \\hostname\sharename as the root
+		matches := regex.FindNamedRegexMatch(`^\\\\(?P<hostname>[^\\]+)\\+(?P<sharename>[^\\]+)\\*(?P<path>[\s\S]*)$`, inputPath)
+		if len(matches) > 0 {
+			root = `\\` + matches["hostname"] + `\` + matches["sharename"]
+			path = clean(matches["path"])
+			return
+		}
+	}
+	s := strings.SplitAfterN(inputPath, separator, 2)
+	root = s[0]
+	if pt.env.GOOS() == environment.WINDOWS {
+		root = strings.TrimSuffix(root, separator)
+	}
+	if len(s) == 2 {
+		path = clean(s[1])
+	}
+	return root, path
+}
+
+func (pt *Path) normalize(inputPath string) string {
+	normalized := inputPath
+	if strings.HasPrefix(normalized, "~") && (len(normalized) == 1 || environment.IsPathSeparator(pt.env, normalized[1])) {
+		normalized = pt.env.Home() + normalized[1:]
+	}
+	switch pt.env.GOOS() {
+	case environment.WINDOWS:
+		normalized = pt.normalizePath(normalized)
+		fallthrough
+	case environment.DARWIN:
+		normalized = strings.ToLower(normalized)
+	}
+	return normalized
 }
 
 func (pt *Path) replaceFolderSeparators(pwd string) string {
 	defaultSeparator := pt.env.PathSeparator()
-	if pwd == defaultSeparator {
-		return pwd
-	}
 	folderSeparator := pt.getFolderSeparator()
 	if folderSeparator == defaultSeparator {
 		return pwd
@@ -403,26 +520,3 @@ func (pt *Path) replaceFolderSeparators(pwd string) string {
 	pwd = strings.ReplaceAll(pwd, defaultSeparator, folderSeparator)
 	return pwd
 }
-
-func (pt *Path) inHomeDir(pwd string) bool {
-	return strings.HasPrefix(pwd, pt.env.Home())
-}
-
-func (pt *Path) rootLocation() string {
-	pwd := pt.getPwd()
-	pwd = strings.TrimPrefix(pwd, pt.env.PathSeparator())
-	splitted := strings.Split(pwd, pt.env.PathSeparator())
-	rootLocation := splitted[0]
-	return rootLocation
-}
-
-func (pt *Path) pathDepth(pwd string) int {
-	splitted := strings.Split(pwd, pt.env.PathSeparator())
-	depth := 0
-	for _, part := range splitted {
-		if part != "" {
-			depth++
-		}
-	}
-	return depth - 1
-}
