@@ -7,6 +7,11 @@ import (
 	"strings"
 )
 
+const (
+	// Fallback to native command
+	NativeFallback properties.Property = "native_fallback"
+)
+
 // ScmStatus represents part of the status of a repository
 type ScmStatus struct {
 	Unmerged   int
@@ -45,10 +50,13 @@ type scm struct {
 	env   environment.Environment
 
 	IsWslSharedPath bool
-	workingFolder   string
-	rootFolder      string
-	realFolder      string // real folder (can be different from current path when in worktrees)
-	command         string
+	CommandMissing  bool
+	Dir             string // actual repo root directory
+
+	workingDir string
+	rootDir    string
+	realDir    string // real directory (can be different from current path when in worktrees)
+	command    string
 }
 
 const (
@@ -92,10 +100,10 @@ func (s *scm) FileContents(folder, file string) string {
 }
 
 func (s *scm) convertToWindowsPath(path string) string {
-	if !s.IsWslSharedPath {
-		return path
+	if s.env.GOOS() == environment.WINDOWS || s.IsWslSharedPath {
+		return s.env.ConvertToWindowsPath(path)
 	}
-	return s.env.ConvertToWindowsPath(path)
+	return path
 }
 
 func (s *scm) convertToLinuxPath(path string) string {
@@ -105,13 +113,28 @@ func (s *scm) convertToLinuxPath(path string) string {
 	return s.env.ConvertToLinuxPath(path)
 }
 
-func (s *scm) getCommand(command string) string {
+func (s *scm) hasCommand(command string) bool {
 	if len(s.command) > 0 {
-		return s.command
+		return true
 	}
-	s.command = command
+	// when in a WSL shared folder, we must use command.exe and convert paths accordingly
+	// for worktrees, stashes, and path to work
+	s.IsWslSharedPath = s.env.InWSLSharedDrive()
 	if s.env.GOOS() == environment.WINDOWS || s.IsWslSharedPath {
-		s.command += ".exe"
+		command += ".exe"
 	}
-	return s.command
+	if s.env.HasCommand(command) {
+		s.command = command
+		return true
+	}
+	s.CommandMissing = true
+	// only use the native fallback when set by the user
+	if s.IsWslSharedPath && s.props.GetBool(NativeFallback, false) {
+		command = strings.TrimSuffix(command, ".exe")
+		if s.env.HasCommand(command) {
+			s.command = command
+			return true
+		}
+	}
+	return false
 }
