@@ -45,8 +45,8 @@ func TestSvnEnabledInWorkingDirectory(t *testing.T) {
 		},
 	}
 	assert.True(t, s.Enabled())
-	assert.Equal(t, fileInfo.Path, s.workingFolder)
-	assert.Equal(t, fileInfo.Path, s.realFolder)
+	assert.Equal(t, fileInfo.Path, s.workingDir)
+	assert.Equal(t, fileInfo.Path, s.realDir)
 }
 
 func TestSvnTemplateString(t *testing.T) {
@@ -234,8 +234,9 @@ R       Moved.File`,
 
 		s := &Svn{
 			scm: scm{
-				env:   env,
-				props: properties.Map{},
+				env:     env,
+				props:   properties.Map{},
+				command: SVNCOMMAND,
 			},
 		}
 		s.setSvnStatus()
