@@ -58,12 +58,14 @@ module.exports = {
         "segments/battery",
         "segments/brewfather",
         "segments/cds",
-        "segments/command",
-        "segments/crystal",
         "segments/cf",
         "segments/cftarget",
         "segments/cmake",
+        "segments/command",
+        "segments/connection",
+        "segments/crystal",
         "segments/dart",
+        "segments/deno",
         "segments/dotnet",
         "segments/executiontime",
         "segments/exit",
@@ -71,7 +73,6 @@ module.exports = {
         "segments/fossil",
         "segments/gcp",
         "segments/git",
-        "segments/poshgit",
         "segments/golang",
         "segments/haskell",
         "segments/ipify",
@@ -83,8 +84,8 @@ module.exports = {
         "segments/lua",
         "segments/nbgv",
         "segments/nightscout",
-        "segments/npm",
         "segments/node",
+        "segments/npm",
         "segments/nx",
         "segments/os",
         "segments/owm",
@@ -110,7 +111,6 @@ module.exports = {
         "segments/time",
         "segments/ui5tooling",
         "segments/wakatime",
-        "segments/wifi",
         "segments/withings",
         "segments/winreg",
         "segments/ytm",
